#include <Python.h>
#include <sip.h>
#include <qimage.h>
#include <qobject.h>

extern SIP_IMPORT QImage *sipForceConvertTo_QImage(PyObject *, int *);

// Create a static module for casting between various classes.

static PyObject * qimage_bits(PyObject *self, PyObject *args)
{
    // This function takes one argument: the object from which the image
    // data is to be extracted.
    PyObject *object, *new_object;
    QImage *cppPtr;
    const char *bits;
    
    if (PyTuple_Size(args) != 1)
        return NULL;
    
    object = PyTuple_GetItem(args, 0);
    
    // Obtain a pointer to the corresponding wrapper object.
    int failed = 0;
    
    cppPtr = (QImage *)sipForceConvertTo_QImage(object, &failed);
    
    if (failed)
        return NULL;
    
    // Read the pointer to the bits.
    bits = (const char *) cppPtr->bits();
    
    new_object = PyString_FromStringAndSize(bits, cppPtr->numBytes());
    
    return new_object;
}

static PyMethodDef qimage_methods[] = {
    { "bits", qimage_bits, METH_VARARGS,
      "bits(object)\n\nReturn the image data as a Python string object." },
    { NULL, NULL } /* sentinel */
};

void init_qimage(void)
{
    PyImport_AddModule("qimage");
    Py_InitModule("qimage", qimage_methods);
}

extern "C"
{
    void initqimage(void)
    {
        init_qimage();
    }
}
